[llvm-commits] CVS: llvm/include/Support/BitSetVector.h

Chris Lattner lattner at cs.uiuc.edu
Sat Jun 21 22:10:01 PDT 2003


Changes in directory llvm/include/Support:

BitSetVector.h updated: 1.6 -> 1.7

---
Log message:

Get rid of WORDSIZE macro which can pollute untold numbers of translation units


---
Diffs of the changes:

Index: llvm/include/Support/BitSetVector.h
diff -u llvm/include/Support/BitSetVector.h:1.6 llvm/include/Support/BitSetVector.h:1.7
--- llvm/include/Support/BitSetVector.h:1.6	Mon Jun 16 19:35:55 2003
+++ llvm/include/Support/BitSetVector.h	Sat Jun 21 22:09:10 2003
@@ -9,12 +9,6 @@
 // We therefore use a vector of bitsets.  The maxmimum size of our sets
 // (i.e., the size of the universal set) can be chosen at creation time.
 //
-// The size of each Bitset is defined by the macro WORDSIZE.
-// 
-// NOTE: The WORDSIZE macro should be made machine-dependent, in order to use
-// 64-bit words or whatever gives most efficient Bitsets on each platform.
-// 
-// 
 // External functions:
 // 
 // bool Disjoint(const BitSetVector& set1, const BitSetVector& set2):
@@ -30,15 +24,13 @@
 #include <vector>
 #include <functional>
 #include <iostream>
-
 #include <assert.h>
 
-#define WORDSIZE (32U)
-
-
 class BitSetVector {
+  enum { BITSET_WORDSIZE = sizeof(long)*8 };
+
   // Types used internal to the representation
-  typedef std::bitset<WORDSIZE> bitword;
+  typedef std::bitset<BITSET_WORDSIZE> bitword;
   typedef bitword::reference reference;
   class iterator;
 
@@ -48,11 +40,13 @@
 
 private:
   // Utility functions for the representation
-  static unsigned NumWords(unsigned Size) { return (Size+WORDSIZE-1)/WORDSIZE;} 
-  static unsigned LastWordSize(unsigned Size) { return Size % WORDSIZE; }
+  static unsigned NumWords(unsigned Size) {
+    return (Size+BITSET_WORDSIZE-1)/BITSET_WORDSIZE;
+  } 
+  static unsigned LastWordSize(unsigned Size) { return Size % BITSET_WORDSIZE; }
 
   // Clear the unused bits in the last word.
   // The unused bits are the high (WORDSIZE - LastWordSize()) bits
   void ClearUnusedBits() {
     unsigned long usedBits = (1U << LastWordSize(size())) - 1;
     bitsetVec.back() &= bitword(usedBits);
@@ -91,7 +85,7 @@
   }
   reference operator[](unsigned n) {
     assert(n  < size() && "BitSetVector: Bit number out of range");
-    unsigned ndiv = n / WORDSIZE, nmod = n % WORDSIZE;
+    unsigned ndiv = n / BITSET_WORDSIZE, nmod = n % BITSET_WORDSIZE;
     return bitsetVec[ndiv][nmod];
   }
   iterator begin() { return iterator::begin(*this); }
@@ -116,7 +110,7 @@
   ///  
   bool test(unsigned n) const {
     assert(n  < size() && "BitSetVector: Bit number out of range");
-    unsigned ndiv = n / WORDSIZE, nmod = n % WORDSIZE;
+    unsigned ndiv = n / BITSET_WORDSIZE, nmod = n % BITSET_WORDSIZE;
     return bitsetVec[ndiv].test(nmod);
   }
   bool any() const {
@@ -203,13 +197,13 @@
 
     // Increment and decrement operators (pre and post)
     iterator& operator++() {
-      if (++currentBit == WORDSIZE)
+      if (++currentBit == BITSET_WORDSIZE)
         { currentBit = 0; if (currentWord < bitvec->size()) ++currentWord; }
       return *this;
     }
     iterator& operator--() {
       if (currentBit == 0) {
-        currentBit = WORDSIZE-1;
+        currentBit = BITSET_WORDSIZE-1;
         currentWord = (currentWord == 0)? bitvec->size() : --currentWord;
       }
       else
@@ -48,11 +40,13 @@
 
   // Clear the unused bits in the last word.
-  // The unused bits are the high (WORDSIZE - LastWordSize()) bits
+  // The unused bits are the high (BITSET_WORDSIZE - LastWordSize()) bits
   void ClearUnusedBits() {
     unsigned long usedBits = (1U << LastWordSize(size())) - 1;





More information about the llvm-commits mailing list